@@ -31,6 +31,10 @@ void CheckNewStrips::dataUpdated(const ComicMetaData &data)
     const QString source = data.identifier;
     QString lastIdentifierSuffix;
 
+    if (!mEngine->isCheckingForUpdates()) {
+        return;
+    }
+
     if (!data.error) {
         lastIdentifierSuffix = data.identifier;
         lastIdentifierSuffix.remove(source);
@@ -48,6 +52,7 @@ void CheckNewStrips::dataUpdated(const ComicMetaData &data)
         mEngine->requestSource(newSource);
     } else {
         mIndex = 0;
+        mEngine->setIsCheckingForUpdates(false);
     }
 }
 
@@ -58,6 +63,8 @@ void CheckNewStrips::start()
         return;
     }
 
+    mEngine->setIsCheckingForUpdates(true);
+
     if (mIndex < mIdentifiers.count()) {
         const QString newSource = mIdentifiers[mIndex] + QLatin1Char(':');
         mEngine->requestSource(newSource);
