@@ -20,12 +20,12 @@ class QtCalendarProvider : public AbstractCalendarProvider
     Q_OBJECT
 
 public:
-    explicit QtCalendarProvider(QObject *parent, CalendarSystem::System calendarSystem);
+    explicit QtCalendarProvider(QObject *parent, CalendarSystem::System calendarSystem, const QDate &startDate, const QDate &endDate, int dateOffset = 0);
     ~QtCalendarProvider() override;
 
     QCalendar::YearMonthDay fromGregorian(const QDate &date) const override;
-    CalendarEvents::CalendarEventsPlugin::SubLabel subLabels(const QDate &date) const override;
+    CalendarEvents::CalendarEventsPlugin::SubLabel subLabel(const QDate &date) const override;
 
 private:
-    const std::unique_ptr<class QtCalendarProviderPrivate> d;
+    const QCalendar m_calendar;
 };
